@@ -419,3 +419,65 @@ ms_get_casefolded_string_list (GtkStringList *strlist)
 
   return casefolded_strlist;
 }
+
+
+const char *
+ms_get_event_id_for_media_role (MsMediaRole role)
+{
+  const char *event_id;
+
+  switch (role) {
+  case MS_MEDIA_ROLE_ALARM:
+    event_id = "alarm-clock-elapsed";
+    break;
+  case MS_MEDIA_ROLE_ALERT:
+    event_id = "cellbroadcast";
+    break;
+  case MS_MEDIA_ROLE_NOTIFICATION:
+    event_id = "message-new-instant";
+    break;
+  case MS_MEDIA_ROLE_PHONE:
+    event_id = "";
+    break;
+  case MS_MEDIA_ROLE_RINGTONE:
+    event_id = "phone-incoming-call";
+    break;
+  case MS_MEDIA_ROLE_MULTIMEDIA:
+  default:
+    event_id = "complete";
+    break;
+  }
+
+  return event_id;
+}
+
+
+const char *
+ms_get_media_role_as_string (MsMediaRole role)
+{
+  const char *media_role;
+
+  switch (role) {
+  case MS_MEDIA_ROLE_ALARM:
+    media_role = "Alarm";
+    break;
+  case MS_MEDIA_ROLE_ALERT:
+    media_role = "Alert";
+    break;
+  case MS_MEDIA_ROLE_NOTIFICATION:
+    media_role = "Notification";
+    break;
+  case MS_MEDIA_ROLE_PHONE:
+    media_role = "Phone";
+    break;
+  case MS_MEDIA_ROLE_RINGTONE:
+    media_role = "Ringtone";
+    break;
+  case MS_MEDIA_ROLE_MULTIMEDIA:
+  default:
+    media_role = "Multimedia";
+    break;
+  }
+
+  return media_role;
+}
